==> openGion6.3.8.5_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF93S.sql <==
/****************************************************************************/
/* GF93 ( 画面項目ﾘﾝｸ )                                                     */
/*                                                                          */
/* Created : 2015/09/17 15:31:10                                            */
/****************************************************************************/
CREATE TABLE GF93 (
   SYSTEM_ID    VARCHAR2 (  10 )                                        /*  10 ｼｽﾃﾑID       */
 , PGID         VARCHAR2 (  30 )                    NOT NULL            /*  20 PG-ID        */
 , NMSYORI      VARCHAR2 ( 100 )                                        /*  30 処理ｸﾞﾙｰﾌﾟ名 */
 , SEQ          NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  40 順           */
 , CLM          VARCHAR2 (  30 )                                        /*  50 項目         */
 , TO_GAMENID   VARCHAR2 (  30 )                                        /*  60 先画面ID     */
 , HREF         VARCHAR2 ( 256 )                                        /*  70 ﾘﾝｸ先URL     */
 , TARGET       VARCHAR2 (  30 )                                        /*  80 ﾀｰｹﾞｯﾄ       */
 , P_KEYS       VARCHAR2 ( 500 )                                        /*  90 引数ｷｰ       */
 , P_VALS       VARCHAR2 ( 500 )                                        /* 100 引数値       */
 , USEGAMENID   VARCHAR2 (  20 )                                        /* 110 画面使用     */
 , USEREDIRECT  VARCHAR2 (  20 )                                        /* 120 ﾘﾀﾞｲﾚｸﾄ使用  */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF93S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF93T00 
  BEFORE INSERT ON GF93
  FOR EACH ROW 
  BEGIN 
    SELECT GF93S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.0.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF93S.sql <==
/****************************************************************************/
/* GF93 ( 画面項目ﾘﾝｸ )                                                     */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF93 (
   SYSTEM_ID    VARCHAR2 (  10 )                                        /*  10 ｼｽﾃﾑID       */
 , PGID         VARCHAR2 (  30 )                    NOT NULL            /*  20 PG-ID        */
 , NMSYORI      VARCHAR2 ( 100 )                                        /*  30 処理ｸﾞﾙｰﾌﾟ名 */
 , SEQ          NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  40 順           */
 , CLM          VARCHAR2 (  30 )                                        /*  50 項目         */
 , TO_GAMENID   VARCHAR2 (  30 )                                        /*  60 先画面ID     */
 , HREF         VARCHAR2 ( 256 )                                        /*  70 ﾘﾝｸ先URL     */
 , TARGET       VARCHAR2 (  30 )                                        /*  80 ﾀｰｹﾞｯﾄ       */
 , P_KEYS       VARCHAR2 ( 500 )                                        /*  90 引数ｷｰ       */
 , P_VALS       VARCHAR2 ( 500 )                                        /* 100 引数値       */
 , USEGAMENID   VARCHAR2 (  20 )                                        /* 110 画面使用     */
 , USEREDIRECT  VARCHAR2 (  20 )                                        /* 120 ﾘﾀﾞｲﾚｸﾄ使用  */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF93S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF93T00 
  BEFORE INSERT ON GF93
  FOR EACH ROW 
  BEGIN 
    SELECT GF93S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
